@@ -1,31 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the Qt Data Visualization module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 or (at your option) any later version
-** approved by the KDE Free Qt Foundation. The licenses are as published by
-** the Free Software Foundation and appearing in the file LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
 #include "scatterchart.h"
 #include <QtDataVisualization/qscatterdataproxy.h>
@@ -37,7 +11,6 @@
 #include <QtDataVisualization/Q3DInputHandler>
 #include <qmath.h>
 #include <qrandom.h>
-using namespace QtDataVisualization;
 
 //#define RANDOM_SCATTER
 
@@ -245,7 +218,7 @@ void ScatterDataModifier::massiveTestAppendAndScroll()
     m_chart->axisZ()->setRange(min, max);
 }
 
-void ScatterDataModifier::setFpsMeasurement(bool enable)
+void ScatterDataModifier::setFpsMeasurement(int enable)
 {
     m_chart->setMeasureFps(enable);
 }
@@ -974,14 +947,14 @@ void ScatterDataModifier::changeRadialLabelOffset(int offset)
     m_chart->setRadialLabelOffset(float(offset) / 100.0f);
 }
 
-void ScatterDataModifier::toggleAxisTitleVisibility(bool enabled)
+void ScatterDataModifier::toggleAxisTitleVisibility(int enabled)
 {
     m_chart->axisX()->setTitleVisible(enabled);
     m_chart->axisY()->setTitleVisible(enabled);
     m_chart->axisZ()->setTitleVisible(enabled);
 }
 
-void ScatterDataModifier::toggleAxisTitleFixed(bool enabled)
+void ScatterDataModifier::toggleAxisTitleFixed(int enabled)
 {
     m_chart->axisX()->setTitleFixed(enabled);
     m_chart->axisY()->setTitleFixed(enabled);
@@ -1010,12 +983,12 @@ void ScatterDataModifier::renderToImage()
     }
 }
 
-void ScatterDataModifier::togglePolar(bool enable)
+void ScatterDataModifier::togglePolar(int enable)
 {
     m_chart->setPolar(enable);
 }
 
-void ScatterDataModifier::toggleStatic(bool enable)
+void ScatterDataModifier::toggleStatic(int enable)
 {
     if (enable)
         m_chart->setOptimizationHints(QAbstract3DGraph::OptimizationStatic);
@@ -1023,7 +996,7 @@ void ScatterDataModifier::toggleStatic(bool enable)
         m_chart->setOptimizationHints(QAbstract3DGraph::OptimizationDefault);
 }
 
-void ScatterDataModifier::toggleOrtho(bool enable)
+void ScatterDataModifier::toggleOrtho(int enable)
 {
     m_chart->setOrthoProjection(enable);
 }
